#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_15_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_15_HPP_INCLUDED

#include <boost/simd/constant/include/constants/oneo_15.hpp>

#endif
